The Changes
===========

v1.4.4
------

1. Make the setup.py, __init__.py, better.
2. Add documents: docs/tests folder, README.rst, MANIFEST.in, nester_pre.py etc.
3. modify format of source distribution, bzip'ed tar-file.
4. Support data Structures: tuple, dict
5. Fixed: String format printing problems
6. support: Python 2.7.x and Python 3.x

v1.4.3
------

1. Make the setup.py better.
2. Add LICENSE.txt .
